@@ -1,4 +1,5 @@
-from .marginals import *
+# Import core
+# --------------------------------------------------
 from .tools import *
 from .core import *
 
@@ -6,10 +7,17 @@ from .core import *
 # --------------------------------------------------
 from .dfply import *
 
+# Marginals uses make_symbolic decorator
+from .marginals import *
+
 # Add functionality to dfply
 from .string_helpers import *
 from .mutate_helpers import *
 
+## Load plotnine
+# --------------------------------------------------
+from plotnine import *
+
 ## Load grama tools
 # --------------------------------------------------
 from .eval_defaults import *
@@ -20,10 +28,19 @@ from .comp_metamodels import *
 from .eval_random import *
 from .eval_tail import *
 from .eval_opt import *
-from .plot_auto import *
+from .eval_contour import *
 from .tran_pivot import *
 from .tran_shapley import *
 from .tran_summaries import *
 from .support import *
+from .tran_is import *
 
 from .fit_synonyms import *
+from .plot_auto import *
+
+## Load extras
+# --------------------------------------------------
+from .eval import *
+from .fit import *
+from .psdr import *
+from .tran import *
